@@ -2,5 +2,5 @@ ARMAtoAR <- function(ar = 0, ma = 0, lag.max=20){
              ARMAtoMA <- stats::ARMAtoMA
              arinv <- -ma
              mainv <- -ar
-             return(round(ARMAtoMA(arinv, mainv, lag.max), 3))
+             return(ARMAtoMA(arinv, mainv, lag.max))
 }
\ No newline at end of file
