@@ -1,9 +1,10 @@
 arma.spec <-
-function(ar=0, ma=0, var.noise=1, n.freq=500, log='n', type=NULL, ...)
+function(ar=0, ma=0, var.noise=1, n.freq=500, log='n', main='from specified model', 
+          frequency=1, ...)
 { 
      plot = graphics::plot     
-	 check <- 0
-	# check causality
+     check <- 0
+    # check causality
      ar.poly <- c(1, -ar)
      z.ar <- base::polyroot(ar.poly)
      if(any(abs(z.ar) <= 1)) {cat("WARNING: Model Not Causal", "\n"); check <- check + 1}  
@@ -18,7 +19,7 @@ function(ar=0, ma=0, var.noise=1, n.freq=500, log='n', type=NULL, ...)
     # check (near) parameter redundancy [i.e. are any roots (approximately) equal]  
        for (i in 1:ar.order) {
        if ( (ar[1] == 0 && ar.order == 1) || (ma[1] == 0 && ma.order ==1) )  break
-       if(any(abs(z.ar[i]-z.ma[1:ma.order]) < 1e-03)) {cat("WARNING: Parameter Redundancy", "\n"); break}
+       if(any(abs(z.ar[i]-z.ma[1:ma.order]) < 1e-01)) {cat("WARNING: Parameter Redundancy", "\n"); break}
        }
     #
     freq <- seq.int(0, 0.5, length.out = n.freq)
@@ -27,14 +28,11 @@ function(ar=0, ma=0, var.noise=1, n.freq=500, log='n', type=NULL, ...)
             cs.ma <- outer(freq, 1:ma.order, function(x, y) cos(2 * pi * x * y)) %*% -ma
             sn.ma <- outer(freq, 1:ma.order, function(x, y) sin(2 * pi * x * y)) %*% -ma                      
     spec <- var.noise*((1 - cs.ma)^2 + sn.ma^2)/((1 - cs.ar)^2 + sn.ar^2)
-    spg.out <- list(freq=freq, spec=spec)
-    class(spg.out) <- "spec"
-    type0 <- 'n' 
-    type1 <- ifelse(is.null(type), 'l', type)
-    plot(spg.out, xlab='frequency', ylab='spectrum', log=log, type=type0, ...)
-    Grid()
-    par(new=TRUE)
-    plot(spg.out, xlab='frequency', ylab='spectrum', log=log, type=type1, ...)
-    return(invisible(spg.out))
+    spg.out <- list(freq=freq*frequency, spec=spec)
+    Ylab='spectrum'
+    if (log == 'y' || log == 'yes' || log == 'dB') { spec = log(spec); Ylab='log(spectrum)' }
+    Xlab = ifelse(frequency>1, paste('frequency', expression('\u00D7'), frequency), 'frequency')
+   tsplot(freq*frequency, spec, xlab=Xlab, ylab=Ylab, main=main, ...)
+   return(invisible(spg.out))
 }
 
