@@ -1,5 +1,6 @@
 lag1.plot <-
-function(series,max.lag=1,corr=TRUE,smooth=TRUE,col=gray(.1), ...){ 
+function(series, max.lag=1, corr=TRUE, smooth=TRUE, col=gray(.1), 
+         lwl=1, bgl ='white', box.col=8, ...){ 
    #
    as.ts = stats::as.ts
    par = graphics::par
@@ -16,14 +17,14 @@ function(series,max.lag=1,corr=TRUE,smooth=TRUE,col=gray(.1), ...){
    pcol=ceiling(max.lag/prow)
    a=stats::acf(series,max.lag,plot=FALSE)$acf[-1]
    old.par <- par(no.readonly = TRUE)
-   par(mfrow=c(prow,pcol), mar=c(2.5, 2.5, 1, 1), mgp=c(1.6,.6,0), cex.main=1, font.main=1)
+   par(mfrow=c(prow,pcol))
   for(h in 1:max.lag){                       
-   plot(stats::lag(series,-h), series, xy.labels=FALSE, main=paste(name1,h,")",sep=""), ylab=name2, xlab="", col=col, panel.first=Grid(), ...) 
+   tsplot(stats::lag(series,-h), series, type='p', xy.labels=FALSE, xlab=paste(name1,h,")",sep=""), ylab=name2, col=col, ...) 
     if (smooth==TRUE) 
     lines(stats::lowess(ts.intersect(stats::lag(series,-h),series)[,1],
-                 ts.intersect(stats::lag(series,-h),series)[,2]), col="red")
+                 ts.intersect(stats::lag(series,-h),series)[,2]), col=2, lwd=lwl)
     if (corr==TRUE)
-    legend("topright", legend=round(a[h], digits=2), text.col ="blue", bg="white", adj=.25, cex = 0.85)
+    legend("topright", legend=round(a[h], digits=2), text.col=4, bg=bgl, adj=.25, cex = 0.85, box.col=box.col)
    on.exit(par(old.par))
    }
 }
