@@ -1,6 +1,6 @@
 sarima.sim <-
 function(ar=NULL, d=0, ma=NULL, sar=NULL, D=0, sma=NULL, S=NULL,
-          n=500, rand.gen=rnorm, burnin=NA, ...){ 
+          n=500, rand.gen=rnorm, burnin=NA, t0=0, ...){ 
   if (length(ar)==1 && ar==0) ar=NULL
   if (length(ma)==1 && ma==0) ma=NULL  
   po = length(ar)
@@ -22,7 +22,6 @@ function(ar=NULL, d=0, ma=NULL, sar=NULL, D=0, sma=NULL, S=NULL,
    }
   num = n + burnin   
   x = .zarima_sim(list(order=c(po,d,qo), ar=ar, ma=ma), n=num, rand.gen=rand.gen, ...)
-  if (burnin>0) { x = x[-(1:burnin)] }
  } else {  
   if (length(sar)==1 && sar==0) sar=NULL
   if (length(sma)==1 && sma==0) sma=NULL 
@@ -35,7 +34,7 @@ function(ar=NULL, d=0, ma=NULL, sar=NULL, D=0, sma=NULL, S=NULL,
   Po = length(sar)
   Qo = length(sma)
   if (S > 0 && Po + Qo + D < 1) 
-     { stop("S > 0 but no seasonal parameters are specified") }
+     { message("Note that S > 0 but no seasonal parameters are specified") }
   if (Po > 0){
    SAR = c(1, rep(0, Po*S))
    SAR[seq(S+1, Po*S+1, by=S)] = -sar
@@ -77,11 +76,10 @@ function(ar=NULL, d=0, ma=NULL, sar=NULL, D=0, sma=NULL, S=NULL,
   if (D > 0){
    x = stats::diffinv(x, lag=S, differences=D)
    }
-  if (burnin > 0) { x = x[-(1:burnin)] }
   } 
 ###
 frq = ifelse(is.null(S),1,S)
-x = ts(x, start=0, frequency=frq)
+x = ts(x[(burnin+1):(burnin+n)], start=t0, frequency=frq)
 return(x)
 }
 
